#
# spec file for package libsmbios
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sonum 2
%define libname libsmbios_c%{sonum}
Name:           libsmbios
VCS: https://src.suse.de/SLFO-pool/libsmbios#d105cecbc7bdaf04565fdef21f01cda3954109c5e864ad2d08d026b0ed37db70
Version:        2.4.3.3.gf01a217
Release:        160000.3.4
Summary:        SMBIOS table library and utilities
License:        GPL-2.0-or-later OR OSL-2.1
Group:          Hardware/Other
URL:            https://github.com/dell/libsmbios
Source:         %{name}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM https://github.com/dell/libsmbios/pull/149 drop unittest.makeSuite (dropped in python 3.13)
Patch:          unittest-drop-makeSuite.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  gettext
BuildRequires:  help2man
BuildRequires:  libcppunit-devel
BuildRequires:  libtool
BuildRequires:  libxml2-devel
BuildRequires:  pkgconfig
BuildRequires:  python-rpm-macros
BuildRequires:  python3-devel
# libsmbios only ever makes sense on intel compatible arches
# no DMI tables on ppc, s390, etc.
ExclusiveArch:  x86_64 ia64 %{ix86}

%description
libsmbios provides a library to interface with the SMBIOS tables. It
also provides extensions for proprietary methods of interfacing with
Dell specific SMBIOS tables.

%lang_package

%package -n %{libname}
Summary:        SMBIOS table interface library
Group:          System/Libraries
Provides:       %{name} = %{version}

%description -n %{libname}
libsmbios provides a library to interface with the SMBIOS tables. It
also provides extensions for proprietary methods of interfacing with
Dell specific SMBIOS tables.

This package provides the C API library.

%package -n python3-smbios
Summary:        Python interface to Libsmbios C library
Group:          System/Libraries
Requires:       %{libname} = %{version}
# We provide only python3 bindings thus obsolete the old ones
Obsoletes:      python-smbios

%description -n python3-smbios
This package provides a Python interface to libsmbios

%package -n smbios-utils
Summary:        Utilities that use libsmbios
Group:          System/Management
Recommends:     %{name}-lang = %{version}
Recommends:     python3-smbios-utils = %{version}
# Give away the bin subpkg and just pull them all here instead of playing with
# metapackages
Provides:       libsmbios-bin = %{version}
Provides:       smbios-utils-bin
Obsoletes:      libsmbios-bin < %{version}
Provides:       libsmbios-unsupported-bin = %{version}
Obsoletes:      libsmbios-unsupported-bin < %{version}

%description -n smbios-utils
Get BIOS information, such as System product name, product id, service tag and
asset tag.

%package -n python3-smbios-utils
Summary:        Python executables that use libsmbios
Group:          System/Management
Requires:       python3-smbios = %{version}
# Former name replacement
Provides:       smbios-utils-python = %{version}

%description -n python3-smbios-utils
Get BIOS information, such as System product name, product id, service tag and
asset tag. Set service and asset tags on Dell machines. Manipulate wireless
cards/bluetooth on Dell laptops. Set BIOS password on select Dell systems.
Update BIOS on select Dell systems. Set LCD brightness on select Dell laptops.

%package -n libsmbios-devel
Summary:        Development headers and archives
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}
Provides:       libsmbios2-devel = %{version}
Obsoletes:      libsmbios2-devel < %{version}

%description -n libsmbios-devel
Libsmbios is a library and utilities that can be used by client programs to get
information from standard BIOS tables, such as the SMBIOS table.

This package contains the headers and .a files necessary to compile new client
programs against libsmbios.

%prep
%autosetup -p1
# That conflicts with --disable-static
sed -i"" "s/ -static//" src/bin/Makefile.am

%build
autoreconf -fvi
export CFLAGS="%{optflags} -fPIE"
export LDFLAGS="-pie"
%configure \
	--disable-static \
	--enable-nls \
	--enable-python \
	--enable-as-needed \
	--enable-doxygen \
	%{nil}
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

# python3 duplicates
%fdupes %{buildroot}%{python3_sitearch}

# include files
mkdir -p %{buildroot}/%{_includedir}
cd src/include
find . -name "*.h" -exec install -m 0644 -D {} %{buildroot}/%{_includedir}/{} \;
cd ../..
cp -a out/public-include/* %{buildroot}%{_includedir}/

%find_lang %{name}

# backwards compatible
mkdir -p %{buildroot}%{_bindir}
ln -s %{_sbindir}/smbios-wireless-ctl %{buildroot}/%{_bindir}/dellWirelessCtl
ln -s smbios-sys-info %{buildroot}/%{_sbindir}/getSystemId
ln -s smbios-wireless-ctl %{buildroot}/%{_sbindir}/dellWirelessCtl
ln -s smbios-lcd-brightness %{buildroot}/%{_sbindir}/dellLcdBrightness

%python3_fix_shebang

%check
%make_build check

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%license COPYING-GPL COPYING-OSL
%license src/bin/getopts_LICENSE.txt
%{_libdir}/libsmbios_c.so.%{sonum}
%{_libdir}/libsmbios_c.so.*
%{_datadir}/locale/en/

%files lang -f %{name}.lang
# english locale should be in the main package
%exclude %{_datadir}/locale/en

%files -n libsmbios-devel
%{_includedir}/smbios
%{_includedir}/smbios_c
%{_libdir}/libsmbios_c.so
%{_libdir}/pkgconfig/*.pc

%files -n smbios-utils
# C utilities
%{_sbindir}/smbios-state-byte-ctl
%{_mandir}/man?/smbios-state-byte-ctl.*
%{_sbindir}/smbios-get-ut-data
%{_mandir}/man?/smbios-get-ut-data.*
%{_sbindir}/smbios-upflag-ctl
%{_mandir}/man?/smbios-upflag-ctl.*
%{_sbindir}/smbios-sys-info-lite
%{_mandir}/man?/smbios-sys-info-lite.*

%files -n python3-smbios
%{python3_sitearch}/*

%files -n python3-smbios-utils
%dir %{_sysconfdir}/libsmbios
%config(noreplace) %{_sysconfdir}/libsmbios/*
# python utilities
%{_sbindir}/smbios-battery-ctl
%{_mandir}/man?/smbios-battery-ctl.*
%{_sbindir}/smbios-sys-info
%{_mandir}/man?/smbios-sys-info.*
%{_sbindir}/smbios-token-ctl
%{_mandir}/man?/smbios-token-ctl.*
%{_sbindir}/smbios-passwd
%{_mandir}/man?/smbios-passwd.*
%{_sbindir}/smbios-wakeup-ctl
%{_mandir}/man?/smbios-wakeup-ctl.*
%{_sbindir}/smbios-wireless-ctl
%{_mandir}/man?/smbios-wireless-ctl.*
%{_sbindir}/smbios-lcd-brightness
%{_mandir}/man?/smbios-lcd-brightness.*
%{_sbindir}/smbios-keyboard-ctl
%{_mandir}/man?/smbios-keyboard-ctl.*
%{_sbindir}/smbios-thermal-ctl
%{_mandir}/man?/smbios-thermal-ctl.*
# used by HAL in old location, so keep it around until HAL is updated.
%{_sbindir}/dellLcdBrightness
%{_sbindir}/getSystemId
%{_sbindir}/dellWirelessCtl
%{_bindir}/dellWirelessCtl
# data files
%{_datadir}/smbios-utils

%changelog
* Wed Feb  5 2025 dmueller@suse.com
- switch to manual service runs
* Thu Jan 30 2025 mmachova@suse.com
- Add unittest-drop-makeSuite.patch to adapt the testsuite to Python 3.13
* Thu Mar 14 2024 pgajdos@suse.com
- remove dependency on /usr/bin/python3 using
  %%python3_fix_shebang macro, [bsc#1212476]
* Tue May  3 2022 fvogt@suse.com
- Replace invalid use of chrpath with patching out -static (boo#1199134)
- Mention the sonum in %%files
- Drop meanwhile unnecessary libsmbios-rpmlintrc
* Fri Jul  9 2021 trenn@suse.de
- Add _service magic
- Update to version 2.4.3.3.gf01a217:
  * Don't rely on support for indirect expansion in the shell
  * Fix configure.ac bashism
  * Fix smbios-upflag-ctl --help results
* Sun Aug 16 2020 dmueller@suse.com
- update to 2.4.3
  * Fixes for WMI based communications
  * Fixes for battery controls
  * Fixes for some segfaults and error handling
* Fri Jan 10 2020 bjorn.lie@gmail.com
- Move /usr/share/locale/en from the -lang package to the main
  package: English is installed on all systems. This avoids
  libsmbios-lang being triggered for installation on english-only
  systems.
- Modernize spec.
* Wed Nov 21 2018 egotthold@suse.com
- Fixed build through adding a recrompress at buildtime and changing the
  Source in the specfile.
* Fri Nov  9 2018 egotthold@suse.de
- Updated _service file to the modern obs_scm, so that the maintenance
  is less time cosuming and the obs needs less space to store the sources.
- Update to version 2.4.2:
  * Fix misspelling in doc/getopt/README
  * Fix bus errors with small memory files (Closes: #58)
  * trivial: fix line endings
  * Correct the location some headers are installed to (Closes: #50)
  * Conditionalize build of man pages properly (Closes: #49)
  * install include headers with make install (Closes: #47)
  * Revert "Allow python34 or python36 to resolve the python3 requirements"
  * Allow python34 or python36 to resolve the python3 requirements
* Fri May 18 2018 tchvatal@suse.com
- Make the lang_package installable by providing the symbol
  required on the libname subpackage
* Mon May 14 2018 tchvatal@suse.com
- Add obsoletes for libsmbios2 to ease upgrading
* Thu Apr  5 2018 tchvatal@suse.com
- Adhere to the packaging guidelines
  * As we build only against tumbleweed do not fuzz around with
    supporting Fedora and Centos
  * Use explicit filelists as it is way more readable
  * Do not play around with %%release as it behaves differently
    compared to RH
- Use package names as mandated by python packaging guidelines
- Use full url to fetch tarball from github...
- Do not mess with permission in %%prep phase, the perms on
  directories and files look correct both in tarball and github
- Make build run parallel make and just configure/make without any
  hassle
- Do not mess with locale generating, it is properly created by make
  already
- Do not install buildlog on user systems, we have OBS for that
- Install manpage with each binary, do not just put all mans in
  python3 subpackage
- Actually run tests rather than playing around with valgrind
- Make sure to do -fPIE build
* Mon Mar 26 2018 jengelh@inai.de
- Update shared library packaging to meet guideline.
- Use find's -exec + strategy.
- Escape all %% signs to %%%% where needed.
* Thu Mar 22 2018 antoine.belvire@opensuse.org
- Update to 2.4.1:
  * Minor fixes submitted for help2man improvements and a signed
    comparison.
  * Fix a crash when used by fwupd [boo#1086732]
- Changes in 2.4.0:
  * Convert all python2 -> python3.
  * Drop libsmbios C++ library.
  * Introduce support for WMI SMM API provided by Linux kernel
    4.15+.
  * Add proper support for SMBIOS 3.0 tables.
  * Fix many many crashers.
  * Clean up long standing coverity errors.
* Fri Feb 23 2018 josef.moellers@suse.com
- Package was ported to python3 by upstream, no functional changes,
  no api changes.
  [bsc#1076409]
* Fri Nov  3 2017 bwiedemann@suse.com
- Do not store build logs in the package to make the
  package build result reproducible
* Mon Oct 30 2017 josef.moellers@suse.com
- Deleted unnecessary sections from SPEC file.
* Fri Sep 22 2017 josef.moellers@suse.com
- Update to version 2.3.3
  Shipping and new DellEMC systems may use dell_rbu driver to
  perform BIOS updates on the system.
  [fate#322804]
* Thu Mar  2 2017 fschnizlein@suse.com
- Update to 2.3.2
  * Drop rbu support
  * Add smbios-battery script
- Fetch source from GitHub
- Remove obsolete patches:
  D libsmbios-2.2.28-fix-bashisms.patch since pkgheader.sh was
  removed
* Wed Jul  6 2016 trenn@suse.de
- Update to latest version 2.3.0 supporting smbios 3.0
- Remove old compatibility binaries
* Sun Nov 30 2014 ledest@gmail.com
- fix bashisms in pkgheader.sh script
- add patches:
  * libsmbios-2.2.28-fix-bashisms.patch
* Tue May  8 2012 cfarrell@suse.com
- license update: GPL-2.0+ or OSL-2.1
  SPDX format (http://www.spdx.org/licenses)
* Sun Jul  3 2011 asterios.dramis@gmail.com
- Update to version 2.2.28:
  * Add a couple placeholder files.
  * Don't bail out on exceptions.
  * Don't print out oem strings anymore, print out reseller (oem) id if it is
    different from dell system id.
  * Add public header interface for new oem system id function
    sysinfo_get_dell_oem_system_id().
  * Rework the system id functions to always return Dell system ID for
    sysinfo_get_dell_system_id(), and add a new api to get the OEM ID.
  * Add compiler support up to gcc 4.8.
- Spec file updates:
  * Removed the fix for GCC 4.6 (fixed upstream).
  * Move %%doc files from the library to the other packages.
  * Minor other updates.
* Fri May 13 2011 asterios.dramis@gmail.com
- Update to version 2.2.27:
  * print out all the OEM strings in smbios-sys-info-lite output.
  * fixup logic error in bayonette id detection which could potentially cause
    segfault.
  * Adding support to compile on solaris.
  * update string extracts for spanish.
  * Fix output of translated unicode strings.
  * By default, python was trying to output all translated strings as ascii,
    which breaks for unicode. Wrap sys.stdout with a streamwriter that outputs
    unicode.
  * add spanish translations.
  * localize messages from import/export token dumps.
  * add another exception case for missing header line.
- Spec file updates:
  * Removed Provides/Obsoletes for libsmbios-libs-0.13.12 in libsmbios2
    (0.13.12 was released at 2007-11-02).
  * Removed smbios-utils meta-package (not needed). Provides/Obsoletes for
    libsmbios-bin and libsmbios-unsupported-bin moved to smbios-utils-python
    and smbios-utils-bin respectively.
  * Fix locales removal if suse_version is not set.
  * Minor other updates.
* Tue May 10 2011 crrodriguez@opensuse.org
- Fix build with GCC 4.6
* Fri Mar 18 2011 asterios.dramis@gmail.com
- Update to version 2.2.26:
  * Lots of changes (see ChangeLog).
- Spec file updates:
  * Major changes in subpackages (based on the package spec file and Fedora
    package):
    + Replaced libsmbios-bin and libsmbios-unsupported-bin with
    smbios-utils-bin and smbios-utils-python (added smbios-utils meta-package
    to Obsolete+Provide them).
    + Added python-smbios and yum-dellsysid subpackages.
    + Removed static subpackage.
  * Changes based on rpmdevtools templates and spec-cleaner run.
  * Changed License: to GPLv2+ or OSL 2.1.
  * Updates in Summary:, Url:, Group: and %%description sections.
  * Updates in Buildrequires:, Requires:, Obsoletes: and Provides: sections.
  * Updates in %%prep, %%build and %%install sections.
  * Removed %%define entries, other conditions, etc.
  * Removed support for suse_version < 1100.
  * Various other changes based on the package spec file.
- Fixed rpmlint warning about "files-duplicate".
- Removed the two patches (fixed upstream).
* Wed Oct 28 2009 crrodriguez@opensuse.org
- libsmbios-devel Requires libstdc++-devel
* Mon Mar  2 2009 crrodriguez@suse.de
- fix build with GCC 4.4
* Fri Nov  7 2008 dkukawka@suse.de
- fixed spec:
  - added Supplements: modalias(dmi:*:[bs]vnD[Ee][Ll][Ll]*:*) for
    libsmbios2 and libsmbios-bin to fix bnc#440814
* Wed Aug 13 2008 ro@suse.de
- change ExcludeArch to ExclusiveArch
* Tue Jul 29 2008 coolo@suse.de
- obsolete old name
* Mon Jul  7 2008 dkukawka@suse.de
- change naming of the lib package because of 'Shared Library
  Packaging Policy' and rpmlint
- updated to latest version v2.0.2
* Mon Jun  2 2008 dkukawka@suse.de
- added: 'Supplements: modalias(dmi:*:[bs]vnD[Ee][Ll][Ll]*:*)'
  to specfile to get the package installed on Dell machines
  (fix for bnc#326765)
* Mon Mar 10 2008 crrodriguez@suse.de
- dont buildrequire libxml, only libxml2 is used
* Fri Mar  7 2008 dmueller@suse.de
- fix documentation permissions
* Tue Jan  8 2008 dkukawka@suse.de
- added new patch:
  - libsmbios-fix-compiler_warning_cgcc.diff
* Sat Dec 29 2007 crrodriguez@suse.de
- fix library-without-ldconfig-postun errors
* Wed Dec 19 2007 dkukawka@suse.de
- updated to new version 0.13.13
* Sun Nov  4 2007 dkukawka@suse.de
- updated to new version 0.13.12:
- removed upstream gone patch:
  - libsmbios-fix-includes.diff
- fixed spec-file:
  - binaries moved from /usr/bin to /usr/sbin
* Tue Oct 16 2007 dkukawka@suse.de
- updated to new version 0.13.10:
  - Fix a couple of failure-to-check-return on fopen. most were
    unit-test code only, but two or three were in regular code.
  - Add hinting to the memory class, so that it can intelligently
    close /dev/mem file handle when it is not needed (which is
    most of the time). it only leaves it open when it is scanning,
    so speed is not impacted.
  - new upstream
- added patches:
  - libsmbios-fix-includes.diff: fix missing includes (needed to
    build in beta tree)
* Wed May  2 2007 dkukawka@suse.de
- updated to new version 0.13.6:
  - critical bugfix to dellBiosUpdate utility to fix packet mode
  - autoconf/automake support for automatically building docs
  - more readable 'make' lines by splitting out env vars
  - remove run_cppunit option... always run unit tests.
  - update autoconf/automake utilities to latest version
  - fix LDFLAGS to not overwrite user entered LDFLAGS
  - add automatic doxygen build of docs
  - fix urls of public repos
  - remove yum repo page in favor of official page from docs
  - split dmi table entry point from smbios table entry point
  - support legacy _DMI_ tables
  - fix support for EFI-based imacs without proper _SM_ anchor
* Mon Mar 26 2007 dkukawka@suse.de
- updated to new version 0.13.4 as requested by DELL maintainer
  - autotools conversion
  - new util dellWirelessCtl to control builtin wireless on Dell
    laptops
* Sat Mar  3 2007 dkukawka@suse.de
- fixed spec file: removed 'rm -rf ${RPM_BUILD_ROOT}' from install
  section
- added ExcludeArch for ppc/ppc64 and s390/s390x
* Wed Feb 28 2007 dkukawka@suse.de
- updated to new version 0.12.4:
  * the package no longer provide bios_update_tools subpackage,
    since they are no longer part of the source
* Fri Feb 10 2006 bwise@suse.de
- put description ib bios_update_check
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Jan 19 2006 ro@suse.de
- provide main package name in one subpackage
  (needed for debuginfo since we do not have a main package here)
* Wed Jan 11 2006 bwhiteley@suse.de
- first build
